.. :changelog:

History
-------

1.0.1 (2015-08-24)
------------------

* Updated PyPI classifiers
* Added docstrings for csstranslator module and other doc fixes


1.0.0 (2015-08-22)
------------------

* Documentation fixes


0.9.6 (2015-08-14)
------------------

* Updated documentation
* Extended test coverage


0.9.5 (2015-08-11)
------------------

* Support for extending SelectorList


0.9.4 (2015-08-10)
------------------

* Try workaround for travis-ci/dpl#253


0.9.3 (2015-08-07)
------------------

* Add base_url argument


0.9.2 (2015-08-07)
------------------

* Rename module unified -> selector and promoted root attribute
* Add create_root_node function


0.9.1 (2015-08-04)
---------------------

* Setup Sphinx build and docs structure
* Build universal wheels
* Rename some leftovers from package extraction


0.9.0 (2015-07-30)
---------------------

* First release on PyPI.
